;; Generated package description from exwm.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "exwm" "0.34.0.20260527.69" "Emacs X Window Manager" '((emacs "27.1") (xelb "0.22") (compat "31")) :commit "4b967c2ded4e61c4014e676b0652b1e32f5b71ba" :authors '(("Chris Feng" . "chris.w.feng@gmail.com")) :maintainer '(("Adrián Medraño Calvo" . "adrian@medranocalvo.com") ("Steven Allen" . "steven@stebalien.com") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("unix") :url "https://github.com/emacs-exwm/exwm")
